Struct distimate::Normal

source ·
pub struct Normal { /* private fields */ }
Represents a modified Normal distribution for estimation purposes.

This Normal distribution is defined by minimum, most likely (mode), and maximum values. It uses these to create an underlying standard Normal distribution, but provides methods to work within the specified range.

Examples

use distimate::prelude::*;
use distimate::Normal;
use approx::assert_relative_eq;

let normal = Normal::new(1.0, 2.0, 3.0).unwrap();
assert_eq!(normal.min(), 1.0);
assert_eq!(normal.mode(), 2.0);
assert_eq!(normal.max(), 3.0);

Implementations

source

impl Normal

source

pub fn new(min: f64, likely: f64, max: f64) -> Result<Self>

Creates a new Normal distribution with the given minimum, most likely (mode), and maximum values.

Arguments
  • min - The minimum value of the distribution
  • likely - The most likely value (mode) of the distribution
  • max - The maximum value of the distribution
Returns

Returns a Result containing the new Normal instance if the parameters are valid, or an Error if the parameters are invalid.

Errors

Returns an error if:

  • min is greater than or equal to max
  • likely is less than min or greater than max
Examples
use distimate::prelude::*;
use distimate::Normal;

let normal = Normal::new(1.0, 2.0, 3.0).unwrap();
assert_eq!(normal.min(), 1.0);
assert_eq!(normal.mode(), 2.0);
assert_eq!(normal.max(), 3.0);